import { v as value2, a as value3 } from './generated-from-main-1-and-2.js';

console.log('main2', value2, value3);
import('./generated-dynamic.js');

export { value2, value3 };
